=== modified file '__init__.py'
--- __init__.py	2022-09-16 15:45:12 +0000
+++ __init__.py	2023-01-31 19:08:09 +0000
@@ -34,6 +34,7 @@
     import importlib.metadata as importlib_metadata
 except ImportError:
     import importlib_metadata
+
 import sys
 
 from packaging.version import Version
@@ -46,7 +47,6 @@
 
 import breezy
 from breezy import commands
-
 from breezy.transport import transport_server_registry
 
 DEFAULT_HOST = '0.0.0.0'

=== modified file 'loggerhead-serve'
--- loggerhead-serve	2020-06-04 20:28:15 +0000
+++ loggerhead-serve	2023-01-31 19:08:09 +0000
@@ -22,6 +22,5 @@
 
 from loggerhead.main import main
 
-
 if __name__ == "__main__":
     main(sys.argv[1:])

=== modified file 'loggerhead.wsgi'
--- loggerhead.wsgi	2021-11-16 00:59:15 +0000
+++ loggerhead.wsgi	2023-01-31 19:08:09 +0000
@@ -14,18 +14,21 @@
 # Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1335  USA
 
 
-import sys
 import os
 import pwd
+import sys
+
 sys.path.insert(0, os.path.dirname(__file__))
 
+from breezy import config as bzrconfig
+from breezy.plugin import load_plugins
+from paste.deploy.config import PrefixMiddleware
 from paste.httpexceptions import HTTPExceptionHandler
+
+from loggerhead.apps.error import ErrorHandlerApp
 from loggerhead.apps.transport import BranchesFromTransportRoot
-from loggerhead.apps.error import ErrorHandlerApp
 from loggerhead.config import LoggerheadConfig
-from breezy import config as bzrconfig
-from paste.deploy.config import PrefixMiddleware
-from breezy.plugin import load_plugins
+
 
 class NotConfiguredError(Exception):
     pass

=== modified file 'loggerhead/apps/__init__.py'
--- loggerhead/apps/__init__.py	2021-12-06 23:30:25 +0000
+++ loggerhead/apps/__init__.py	2023-01-31 19:08:09 +0000
@@ -2,7 +2,7 @@
 
 import os
 
-from paste import urlparser, fileapp
+from paste import fileapp, urlparser
 
 from ..util import convert_file_errors
 

=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2021-12-06 23:30:25 +0000
+++ loggerhead/apps/branch.py	2023-01-31 19:08:09 +0000
@@ -22,28 +22,25 @@
 
 import breezy.branch
 import breezy.errors
-from breezy.hooks import Hooks
 import breezy.lru_cache
 from breezy import urlutils
-
-from paste import request
-from paste import httpexceptions
-
-from ..apps import static_app, health_app
+from breezy.hooks import Hooks
+from paste import httpexceptions, request
+
+from .. import util
+from ..apps import health_app, static_app
 from ..controllers.annotate_ui import AnnotateUI
-from ..controllers.view_ui import ViewUI
 from ..controllers.atom_ui import AtomUI
 from ..controllers.changelog_ui import ChangeLogUI
 from ..controllers.diff_ui import DiffUI
-from ..controllers.download_ui import DownloadUI, DownloadTarballUI
+from ..controllers.download_ui import DownloadTarballUI, DownloadUI
 from ..controllers.filediff_ui import FileDiffUI
 from ..controllers.inventory_ui import InventoryUI
 from ..controllers.revision_ui import RevisionUI
 from ..controllers.revlog_ui import RevLogUI
 from ..controllers.search_ui import SearchUI
+from ..controllers.view_ui import ViewUI
 from ..history import History
-from .. import util
-
 
 _DEFAULT = object()
 

=== modified file 'loggerhead/apps/transport.py'
--- loggerhead/apps/transport.py	2018-10-20 11:09:30 +0000
+++ loggerhead/apps/transport.py	2023-01-31 19:08:09 +0000
@@ -18,20 +18,18 @@
 
 import threading
 
+import breezy.ui
 from breezy import branch, errors, lru_cache, urlutils
+from breezy.bzr.smart import request
 from breezy.config import LocationConfig
-from breezy.bzr.smart import request
-import breezy.ui
 from breezy.transport import get_transport
 from breezy.transport.http import wsgi
-
+from paste import httpexceptions, urlparser
 from paste.request import path_info_pop
-from paste import httpexceptions
-from paste import urlparser
 
 from .. import util
+from ..apps import favicon_app, robots_app, static_app
 from ..apps.branch import BranchWSGIApp
-from ..apps import favicon_app, robots_app, static_app
 from ..controllers.directory_ui import DirectoryUI
 
 

=== modified file 'loggerhead/changecache.py'
--- loggerhead/changecache.py	2021-11-15 14:40:11 +0000
+++ loggerhead/changecache.py	2023-01-31 19:08:09 +0000
@@ -26,12 +26,11 @@
 cached a change, it's good forever.
 """
 
-import pickle
 import marshal
 import os
+import pickle
 import tempfile
 import zlib
-
 from sqlite3 import dbapi2
 
 # We take an optimistic approach to concurrency here: we might do work twice

=== modified file 'loggerhead/config.py'
--- loggerhead/config.py	2020-06-04 19:43:36 +0000
+++ loggerhead/config.py	2023-01-31 19:08:09 +0000
@@ -13,9 +13,9 @@
 #
 """Configuration tools for Loggerhead."""
 
-from optparse import OptionParser
 import sys
 import tempfile
+from optparse import OptionParser
 
 from breezy import config
 

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2020-07-08 17:14:19 +0000
+++ loggerhead/controllers/__init__.py	2023-01-31 19:08:09 +0000
@@ -21,14 +21,11 @@
 import time
 
 import breezy.errors
-
 from breezy import osutils
-
 from paste.httpexceptions import HTTPNotFound, HTTPSeeOther
-from paste.request import path_info_pop, parse_querystring
+from paste.request import parse_querystring, path_info_pop
 
-from .. import templates
-from .. import util
+from .. import templates, util
 from ..templatefunctions import templatefunctions
 from ..zptsupport import load_template
 

=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2022-07-06 12:45:28 +0000
+++ loggerhead/controllers/annotate_ui.py	2023-01-31 19:08:09 +0000
@@ -16,11 +16,12 @@
 # Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1335  USA
 #
 
+import itertools
 from datetime import datetime
-import itertools
 
+from .. import util
 from ..controllers.view_ui import ViewUI
-from .. import util
+
 
 class AnnotateUI(ViewUI):
 

=== modified file 'loggerhead/controllers/changelog_ui.py'
--- loggerhead/controllers/changelog_ui.py	2022-07-06 12:45:28 +0000
+++ loggerhead/controllers/changelog_ui.py	2023-01-31 19:08:09 +0000
@@ -20,10 +20,9 @@
 
 import json
 
+from breezy import osutils, urlutils
 from paste.httpexceptions import HTTPServerError
 
-from breezy import osutils, urlutils
-
 from .. import util
 from ..controllers import TemplatedBranchView
 

=== modified file 'loggerhead/controllers/diff_ui.py'
--- loggerhead/controllers/diff_ui.py	2018-10-20 13:45:31 +0000
+++ loggerhead/controllers/diff_ui.py	2023-01-31 19:08:09 +0000
@@ -16,13 +16,12 @@
 # Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1335  USA
 #
 
+import time
 from io import BytesIO
-import time
-
-from paste.request import path_info_pop, parse_querystring
 
 from breezy.diff import show_diff_trees
 from breezy.revision import NULL_REVISION
+from paste.request import parse_querystring, path_info_pop
 
 from ..controllers import TemplatedBranchView
 

=== modified file 'loggerhead/controllers/download_ui.py'
--- loggerhead/controllers/download_ui.py	2022-08-31 14:04:38 +0000
+++ loggerhead/controllers/download_ui.py	2023-01-31 19:08:09 +0000
@@ -21,14 +21,13 @@
 import mimetypes
 import urllib
 
-from breezy.errors import (
-    NoSuchId,
-    NoSuchRevision,
-    )
+from breezy.errors import NoSuchId, NoSuchRevision
+
 try:
     from breezy.transport import NoSuchFile
 except ImportError:
     from breezy.errors import NoSuchFile
+
 from breezy import osutils, urlutils
 from paste import httpexceptions
 from paste.request import path_info_pop

=== modified file 'loggerhead/controllers/error_ui.py'
--- loggerhead/controllers/error_ui.py	2018-10-20 13:45:31 +0000
+++ loggerhead/controllers/error_ui.py	2023-01-31 19:08:09 +0000
@@ -16,11 +16,11 @@
 # Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1335  USA
 #
 
+import traceback
 from io import StringIO
-import traceback
 
+from .. import util
 from ..controllers import TemplatedBranchView
-from .. import util
 
 
 class ErrorUI(TemplatedBranchView):

=== modified file 'loggerhead/controllers/filediff_ui.py'
--- loggerhead/controllers/filediff_ui.py	2022-08-29 16:33:16 +0000
+++ loggerhead/controllers/filediff_ui.py	2023-01-31 19:08:09 +0000
@@ -1,14 +1,12 @@
 from io import BytesIO
 
-from breezy import (
-    diff,
-    errors,
-    urlutils,
-    )
+from breezy import diff, errors, urlutils
+
 try:
     from breezy.transport import NoSuchFile
 except ImportError:
     from breezy.errors import NoSuchFile
+
 from breezy.tree import find_previous_path
 
 from .. import util

=== modified file 'loggerhead/controllers/inventory_ui.py'
--- loggerhead/controllers/inventory_ui.py	2022-07-06 12:45:28 +0000
+++ loggerhead/controllers/inventory_ui.py	2023-01-31 19:08:09 +0000
@@ -22,20 +22,14 @@
 import posixpath
 import urllib
 
-from paste.httpexceptions import HTTPNotFound, HTTPMovedPermanently
-
-from breezy import (
-    errors,
-    osutils,
-    urlutils,
-    )
+from breezy import errors, osutils, urlutils
 from breezy.revision import is_null as is_null_rev
+from paste.httpexceptions import HTTPMovedPermanently, HTTPNotFound
 
 from .. import util
 from ..controllers import TemplatedBranchView
 
 
-
 def dirname(path):
     if path is not None:
         path = path.rstrip('/')

=== modified file 'loggerhead/controllers/revision_ui.py'
--- loggerhead/controllers/revision_ui.py	2022-07-06 12:45:28 +0000
+++ loggerhead/controllers/revision_ui.py	2023-01-31 19:08:09 +0000
@@ -19,15 +19,13 @@
 
 import json
 
+from breezy import urlutils
 from paste.httpexceptions import HTTPServerError
 
-from breezy import urlutils
-
 from .. import util
 from ..controllers import TemplatedBranchView
 from ..controllers.filediff_ui import diff_chunks_for_file
 
-
 DEFAULT_LINE_COUNT_LIMIT = 3000
 
 

=== modified file 'loggerhead/controllers/search_ui.py'
--- loggerhead/controllers/search_ui.py	2018-10-20 11:09:30 +0000
+++ loggerhead/controllers/search_ui.py	2023-01-31 19:08:09 +0000
@@ -16,8 +16,8 @@
 # Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1335  USA
 #
 
+from .. import search
 from ..controllers import TemplatedBranchView
-from .. import search
 
 
 class SearchUI(TemplatedBranchView):

=== modified file 'loggerhead/controllers/view_ui.py'
--- loggerhead/controllers/view_ui.py	2022-08-29 16:33:16 +0000
+++ loggerhead/controllers/view_ui.py	2023-01-31 19:08:09 +0000
@@ -19,28 +19,20 @@
 
 import os
 
-from breezy.errors import (
-    BinaryFile,
-    NoSuchId,
-    NoSuchRevision,
-    )
+from breezy.errors import BinaryFile, NoSuchId, NoSuchRevision
+
 try:
     from breezy.transport import NoSuchFile
 except ImportError:
     from breezy.errors import NoSuchFile
-from breezy import (
-    osutils,
-    urlutils,
-    )
+
 import breezy.textfile
-
-from paste.httpexceptions import (
-    HTTPBadRequest,
-    HTTPMovedPermanently,
-    HTTPNotFound,
-    )
+from breezy import osutils, urlutils
+from paste.httpexceptions import (HTTPBadRequest, HTTPMovedPermanently,
+                                  HTTPNotFound)
 
 from ..controllers import TemplatedBranchView
+
 try:
     from ..highlight import highlight
 except ImportError:

=== modified file 'loggerhead/daemon.py'
--- loggerhead/daemon.py	2018-10-20 11:27:37 +0000
+++ loggerhead/daemon.py	2023-01-31 19:08:09 +0000
@@ -34,7 +34,7 @@
     else:
         os._exit(0)     # Exit parent of the first child.
 
-    import resource            # Resource usage information.
+    import resource  # Resource usage information.
     maxfd = resource.getrlimit(resource.RLIMIT_NOFILE)[1]
     if (maxfd == resource.RLIM_INFINITY):
         maxfd = MAXFD

=== modified file 'loggerhead/highlight.py'
--- loggerhead/highlight.py	2022-04-03 12:41:18 +0000
+++ loggerhead/highlight.py	2023-01-31 19:08:09 +0000
@@ -16,12 +16,12 @@
 # Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1335  USA
 #
 
+from html import escape
+
 import breezy.osutils
-from html import escape
-
 from pygments import highlight as _highlight_func
-from pygments.lexers import guess_lexer, guess_lexer_for_filename, TextLexer
 from pygments.formatters import HtmlFormatter
+from pygments.lexers import TextLexer, guess_lexer, guess_lexer_for_filename
 from pygments.util import ClassNotFound
 
 DEFAULT_PYGMENT_STYLE = 'colorful'

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2022-08-29 16:33:16 +0000
+++ loggerhead/history.py	2023-01-31 19:08:09 +0000
@@ -34,21 +34,20 @@
 import textwrap
 import threading
 
-from breezy import tag
 import breezy.branch
 import breezy.delta
 import breezy.errors
 import breezy.foreign
 import breezy.osutils
 import breezy.revision
+from breezy import tag
 
 try:
     from breezy.transport import NoSuchFile
 except ImportError:
     from breezy.errors import NoSuchFile
 
-from . import search
-from . import util
+from . import search, util
 from .wholehistory import compute_whole_history_data
 
 

=== modified file 'loggerhead/load_test.py'
--- loggerhead/load_test.py	2022-08-29 16:33:16 +0000
+++ loggerhead/load_test.py	2023-01-31 19:08:09 +0000
@@ -63,17 +63,12 @@
 this.
 """
 
+import json
 import threading
 import time
-from queue import Queue, Empty
-
-import json
-
-from breezy import (
-    errors,
-    transport,
-    urlutils,
-    )
+from queue import Empty, Queue
+
+from breezy import errors, transport, urlutils
 
 try:
     from breezy.transport import NoSuchFile

=== modified file 'loggerhead/lsprof.py'
--- loggerhead/lsprof.py	2021-11-15 14:40:11 +0000
+++ loggerhead/lsprof.py	2023-01-31 19:08:09 +0000
@@ -6,8 +6,9 @@
 # instead of just the Stats object
 
 import sys
+import threading
 from threading import get_ident
-import threading
+
 from _lsprof import Profiler, profiler_entry
 
 __all__ = ['profile', 'Stats']

=== modified file 'loggerhead/main.py'
--- loggerhead/main.py	2022-08-08 16:33:50 +0000
+++ loggerhead/main.py	2023-01-31 19:08:09 +0000
@@ -21,19 +21,18 @@
 import os
 import sys
 
+from breezy.location import location_to_url
 from breezy.plugin import load_plugins
-from breezy.location import location_to_url
-
 from paste import httpserver
 from paste.httpexceptions import HTTPExceptionHandler, HTTPInternalServerError
 from paste.translogger import TransLogger
 
 from . import __version__
-from .apps.transport import (
-    BranchesFromTransportRoot, UserBranchesFromTransportRoot)
+from .apps.error import ErrorHandlerApp
+from .apps.transport import (BranchesFromTransportRoot,
+                             UserBranchesFromTransportRoot)
 from .config import LoggerheadConfig
 from .util import Reloader
-from .apps.error import ErrorHandlerApp
 
 
 def get_config_and_base(args):

=== modified file 'loggerhead/templatefunctions.py'
--- loggerhead/templatefunctions.py	2022-08-08 16:33:50 +0000
+++ loggerhead/templatefunctions.py	2023-01-31 19:08:09 +0000
@@ -16,18 +16,13 @@
 
 import os
 
+import breezy
 import pkg_resources
-
-import breezy
 from breezy import urlutils
 
-from . import (
-    __version__,
-    __revision__,
-    )
+from . import __revision__, __version__
+from .util import html_format
 from .zptsupport import zpt
-from .util import html_format
-
 
 templatefunctions = {}
 

=== modified file 'loggerhead/tests/test_controllers.py'
--- loggerhead/tests/test_controllers.py	2022-09-17 13:07:55 +0000
+++ loggerhead/tests/test_controllers.py	2023-01-31 19:08:09 +0000
@@ -20,23 +20,13 @@
 import tarfile
 import tempfile
 
-from paste.fixture import (
-    AppError,
-    )
+from paste.fixture import AppError
 from paste.httpexceptions import HTTPNotFound
-
-from testtools.matchers import (
-    Matcher,
-    Mismatch,
-    )
+from testtools.matchers import Matcher, Mismatch
 
 from ..apps.branch import BranchWSGIApp
 from ..controllers.annotate_ui import AnnotateUI
-from .test_simple import (
-    BasicTests,
-    consume_app,
-    TestWithSimpleTree,
-    )
+from .test_simple import BasicTests, TestWithSimpleTree, consume_app
 
 
 class TestInventoryUI(BasicTests):

=== modified file 'loggerhead/tests/test_history.py'
--- loggerhead/tests/test_history.py	2018-10-20 13:45:31 +0000
+++ loggerhead/tests/test_history.py	2023-01-31 19:08:09 +0000
@@ -17,14 +17,10 @@
 
 """Direct tests of the loggerhead/history.py module"""
 
-from breezy.foreign import (
-    ForeignRevision,
-    ForeignVcs,
-    VcsMapping,
-    )
-
 from datetime import datetime
+
 from breezy import tag, tests
+from breezy.foreign import ForeignRevision, ForeignVcs, VcsMapping
 
 from .. import history as _mod_history
 

=== modified file 'loggerhead/tests/test_http_head.py'
--- loggerhead/tests/test_http_head.py	2018-10-20 14:21:37 +0000
+++ loggerhead/tests/test_http_head.py	2023-01-31 19:08:09 +0000
@@ -22,7 +22,6 @@
 
 from ..apps import http_head
 
-
 content = [b"<html>",
            b"<head><title>Listed</title></head>",
            b"<body>Content</body>",

=== modified file 'loggerhead/tests/test_load_test.py'
--- loggerhead/tests/test_load_test.py	2021-11-15 14:40:11 +0000
+++ loggerhead/tests/test_load_test.py	2023-01-31 19:08:09 +0000
@@ -13,8 +13,8 @@
 """Tests for the load testing code."""
 
 import socket
+import threading
 import time
-import threading
 from queue import Empty
 
 from breezy import tests
@@ -22,7 +22,6 @@
 
 from .. import load_test
 
-
 empty_script = """{
     "parameters": {},
     "requests": []

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2022-07-06 12:45:28 +0000
+++ loggerhead/tests/test_simple.py	2023-01-31 19:08:09 +0000
@@ -17,24 +17,21 @@
 
 from __future__ import absolute_import
 
-from html import escape
 import json
 import logging
 import re
+from html import escape
 from io import BytesIO
 
+from breezy import config
 from breezy.tests import TestCaseWithTransport
 from configobj import ConfigObj
-from breezy import config
+from paste.fixture import TestApp
+from paste.httpexceptions import HTTPExceptionHandler, HTTPMovedPermanently
 
 from ..apps.branch import BranchWSGIApp
 from ..apps.http_head import HeadMiddleware
-from paste.fixture import TestApp
-from paste.httpexceptions import HTTPExceptionHandler, HTTPMovedPermanently
-
-from .fixtures import (
-    SampleBranch,
-    )
+from .fixtures import SampleBranch
 
 
 class BasicTests(TestCaseWithTransport):

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2022-07-06 12:45:28 +0000
+++ loggerhead/util.py	2023-01-31 19:08:09 +0000
@@ -24,20 +24,18 @@
 import base64
 import datetime
 import logging
+import os
 import re
 import struct
+import subprocess
+import sys
 import threading
 import time
-import sys
-import os
-import subprocess
-
 from xml.etree import ElementTree as ET
 
+import bleach
 from breezy import urlutils
 
-import bleach
-
 log = logging.getLogger("loggerhead.controllers")
 
 
@@ -506,8 +504,9 @@
 def lsprof(f):
 
     def _f(*a, **kw):
+        import cPickle
+
         from .loggerhead.lsprof import profile
-        import cPickle
         z = time.time()
         ret, stats = profile(f, *a, **kw)
         log.debug('Finished profiled %s in %d msec.' % (f.__name__,
@@ -650,6 +649,7 @@
             return application(environ, start_response)
         except (IOError, OSError) as e:
             import errno
+
             from paste import httpexceptions
             if e.errno == errno.ENOENT:
                 raise httpexceptions.HTTPNotFound()

=== modified file 'loggerhead/wholehistory.py'
--- loggerhead/wholehistory.py	2020-05-06 19:18:04 +0000
+++ loggerhead/wholehistory.py	2023-01-31 19:08:09 +0000
@@ -20,7 +20,7 @@
 import logging
 import time
 
-from breezy.revision import is_null, NULL_REVISION
+from breezy.revision import NULL_REVISION, is_null
 from breezy.tsort import merge_sort
 
 

=== modified file 'loggerhead/zptsupport.py'
--- loggerhead/zptsupport.py	2022-08-08 16:33:50 +0000
+++ loggerhead/zptsupport.py	2023-01-31 19:08:09 +0000
@@ -16,9 +16,9 @@
 """Support for Zope Page Templates using the Chameleon library."""
 
 import os
+import re
+
 import pkg_resources
-import re
-
 from chameleon import PageTemplate
 
 _zpt_cache = {}

